Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Source ¶
type Source interface {
// Uint64 returns a random number in [0, MaxUint64] and advances the
// generator's state.
Uint64() uint64
}
type Uniform ¶
type Uniform interface {
Initialize(sampleRange uint64)
// Sample returns length numbers in the range [0,sampleRange). If there
// aren't enough numbers in the range, false is returned. If length is
// negative the implementation may panic.
Sample(length int) ([]uint64, bool)
Next() (uint64, bool)
Reset()
}
Uniform samples values without replacement in the provided range
func NewDeterministicUniform ¶
NewDeterministicUniform returns a new sampler
Click to show internal directories.
Click to hide internal directories.